.. _utilities:

.. module:: dynts.utils

==========================
Utilities
==========================

Timeseries wrappers
============================


As Binary Tree
~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: dynts.utils.asbtree
   :members:
   :member-order: bysource
   
   

As Hash Table
~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: dynts.utils.ashash
   :members:
   :member-order: bysource
   
   

Iterators
================================

.. automodule:: dynts.utils.iterators
   :members:  